============
``psyclone``
============

.. automodule:: psyclone

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.alg_gen
   psyclone.configuration
   psyclone.core
   psyclone.domain
   psyclone.doxy_main_page
   psyclone.dynamo0p3
   psyclone.errors
   psyclone.expression
   psyclone.f2pygen
   psyclone.gen_kernel_stub
   psyclone.generator
   psyclone.gocean1p0
   psyclone.kernel_tools
   psyclone.line_length
   psyclone.nemo
   psyclone.parse
   psyclone.profiler
   psyclone.psyGen
   psyclone.psyad
   psyclone.psyir
   psyclone.tests
   psyclone.transformations
   psyclone.version
   psyclone.virtual_utils

.. currentmodule:: psyclone
